@@ -5,7 +5,7 @@
 (defparameter *autoconf-prefix* "/usr/local")
 (defparameter *autoconf-exec_prefix* "/usr/local")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.38.1")
+(defparameter *autoconf-version* "5.40.0")
 (defparameter *autoconf-libdir* "/usr/local/lib")
 (defparameter *autoconf-libexecdir* "/usr/local/libexec")
 (defparameter *autoconf-datadir* "/usr/local/share")
@@ -17,6 +17,9 @@
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-windows* "false")
 (defparameter *autoconf-ld-flags* "")
+
+;; This will be T if this was a lisp-only build
+(defparameter *autoconf-lisp-only-build* (eq t '@lisp_only_build@))
  
 (defparameter *maxima-source-root* "/home/vttoth/dev/maxima")
 (defparameter *maxima-default-layout-autotools* "true")
