@@ -60,8 +60,9 @@ or if apply is being used are printed.")
 (defvar rulefcnl nil)
 (defvar featurel
   '($integer $noninteger $even $odd $rational $irrational $real $imaginary $complex
-             $analytic $increasing $decreasing $oddfun $evenfun $posfun $constant
-             $commutative $lassociative $rassociative $symmetric $antisymmetric))
+    $analytic $increasing $decreasing $oddfun $evenfun $posfun $constant
+    $commutative $lassociative $rassociative $symmetric $antisymmetric
+    $integervalued))
 
 (defmvar $features (cons '(mlist simp) (append featurel nil)))
 (defmvar $%enumer nil)
@@ -99,18 +100,17 @@ or if apply is being used are printed.")
 (defmfun mapply1 (fn args fnname form)
   (declare (special aryp))
   (cond ((atom fn)
-	 (cond ((atom fn)
-		(cond ((functionp fn)
-		       (apply fn args))
-              ((and (symbolp fn) (fboundp fn) (not (macro-function fn)))
-               (mapply1 (symbol-function fn) args fn form))
-		      ((and (symbolp fn) (symbol-array fn))
-		       (mapply1 (symbol-array fn) args fn form))
-		      (t
-		       (setq fn (getopr fn))
-		       (badfunchk fnname fn nil)
-		       (let ((noevalargs t))
-			 (meval (cons (ncons fn) args))))))))
+	 (cond ((functionp fn)
+		(apply fn args))
+	       ((and (symbolp fn) (fboundp fn) (not (macro-function fn)))
+		(mapply1 (symbol-function fn) args fn form))
+	       ((and (symbolp fn) (symbol-array fn))
+		(mapply1 (symbol-array fn) args fn form))
+	       (t
+		(setq fn (getopr fn))
+		(badfunchk fnname fn nil)
+		(let ((noevalargs t))
+		  (meval (cons (ncons fn) args))))))
 
 	;; GCL considers interpreted functions and lambdas to be non-atoms
 	#+gcl((functionp fn)
@@ -125,12 +125,12 @@ or if apply is being used are printed.")
 	((eq (car fn) 'lambda)
 	 (apply (coerce fn 'function) args))
 	((eq (caar fn) 'lambda) (mlambda fn args fnname t form))
-	((eq (caar fn) 'mquote) (cons (cdr fn) args))
+	((eq (caar fn) 'mquote) (cons (append (cdr fn) aryp) args))
 	((and aryp (member (caar fn) '(mlist $matrix) :test #'eq))
 	 (if (not (or (= (length args) 1)
 		      (and (eq (caar fn) '$matrix) (= (length args) 2))))
 	     (merror (intl:gettext "apply: wrong number of indices; found: ~M") (cons '(mlist) args)))
-	 (if (member 0 args :test #'eq)
+	 (if (member 0 args)
 	     (merror (intl:gettext "apply: no such ~M element: ~M") (if (eq (caar fn) 'mlist) (intl:gettext "list") (intl:gettext "matrix"))
 		     `((mlist) ,@args)))
 	 (do ((args1 args (cdr args1)))
@@ -141,10 +141,8 @@ or if apply is being used are printed.")
 	     (merror (intl:gettext "apply: subscript must be an integer; found: ~M") (car args1)))))
 	(aryp
 	 (cons '(mqapply array) (cons fn args)))
-	((member 'array (cdar fn) :test #'eq)
-	 (cons '(mqapply) (cons fn args)))
 	(t
-	 (badfunchk fnname fn t))))
+	 (cons '(mqapply) (cons fn args)))))
 
 ;; the last argument to mapply1 for the lineinfo is not correct here..
 (defmfun mcall (fn &rest args)
@@ -217,13 +215,11 @@ is EQ to FNNAME if the latter is non-NIL."
 	     (vector-push fnname ar)
 	     (mbind finish2032 args fnname)
 	     (setq finish2033 t)
-	     (prog1
-		 (let ((aexprp (and aexprp (not (atom (caddr fn)))
-				    (eq (caar (caddr fn)) 'lambda))))
-		   (cond ((null (cddr fn)) (merror (intl:gettext "lambda: no body present.")))
-			 ((cdddr fn) (mevaln (cddr fn)))
-			 (t (meval (caddr fn)))))
-	       nil))
+	     (let ((aexprp (and aexprp (not (atom (caddr fn)))
+				(eq (caar (caddr fn)) 'lambda))))
+	       (cond ((null (cddr fn)) (merror (intl:gettext "lambda: no body present.")))
+		     ((cdddr fn) (mevaln (cddr fn)))
+		     (t (meval (caddr fn))))))
 	(if finish2033
 	    (progn
 	      (incf (fill-pointer *mlambda-call-stack*) -5)
@@ -245,7 +241,7 @@ is EQ to FNNAME if the latter is non-NIL."
   (destructuring-let (((fn . argl) (cdr form)) (aexprp))
     (unless (mquotep fn) (setq fn (meval fn)))
     (cond ((atom fn)
-	   (meval (cons (cons fn aryp) argl)))
+	   (meval (cons (cons (amperchk fn) aryp) argl)))
 	  ((eq (caar fn) 'lambda)
 	   (if aryp
 	       (merror (intl:gettext "lambda: cannot apply lambda as an array function."))
@@ -289,7 +285,7 @@ is EQ to FNNAME if the latter is non-NIL."
                   (member form (cdr $values) :test #'eq)
                   (not (member form *refchkl* :test #'eq)))
          (setq *refchkl* (cons form *refchkl*))
-         (mtell (intl:gettext "evaluation: ~:M has a value.~%") form))
+         (mtell (intl:gettext "evaluation: ~:M has the value ~:M.~%") form val))
        (return val)))
     ((or (and (atom (car form))
               (setq form (cons (ncons (car form)) (cdr form))))
@@ -303,7 +299,7 @@ is EQ to FNNAME if the latter is non-NIL."
                      (member (caar form)
                              '(mplus mtimes mexpt mnctimes) :test #'eq))
                 (go c))
-               ;; dont bother pushing mplus and friends on *baktrcl*
+               ;; don't bother pushing mplus and friends on *baktrcl*
                ;; should maybe even go below aryp.
                ((and *mdebug*
                      (progn
@@ -325,7 +321,7 @@ is EQ to FNNAME if the latter is non-NIL."
          (setq u
                (or (safe-getl (caar form) '(noun))
                    (and *nounsflag*
-                        (eq (getcharn (caar form) 1) #\%)
+                        (and (symbolp (caar form)) (eql (getcharn (caar form) 1) #\%))
                         (not (or (getl-lm-fcn-prop (caar form) '(subr))
                                  (safe-getl (caar form) '(mfexpr*))))
                         (prog2 ($verbify (caar form))
@@ -415,10 +411,10 @@ is EQ to FNNAME if the latter is non-NIL."
      (mapply1 (caar form) (mevalargs (cdr form)) (caar form) form))))
 
 (defun getl-lm-fcn-prop (sym props &aux fn typ)
-  (check-arg sym symbolp "symbol")
   (setq fn sym)
   (cond ((functionp fn)
 	 (setq typ 'subr))
+	((not (symbolp sym))) ;; eventually return nil if not a symbol
 	((macro-function sym)
 	 (setq typ 'macro))
 	((setq fn (symbol-array sym))
@@ -482,7 +478,11 @@ wrapper for this."
 			"Expected a maxima function designator but got NIL.")
 		(merror (intl:gettext "~M arguments supplied to ~M; found: ~M")
 			(if vars (intl:gettext "Too few") (intl:gettext "Too many"))
-			(cons (ncons fnname) lamvars)
+			(if (and (consp fnname)
+				 (consp (car fnname))
+				 (eq (caar fnname) 'lambda))
+			    fnname
+			    (cons (ncons fnname) lamvars))
 			(cons '(mlist) fnargs)))))
     (let ((var (car vars)))
       (if (not (symbolp var))
@@ -628,7 +628,7 @@ wrapper for this."
 		     (and (not (atom x))
 			  (memalike (caar x) (cdr $setcheck))))
 		 (not (eq x y)))
-	    (displa (list '(mtext) (disp2 x) '| set to | y))
+	    (mtell (intl:gettext "~:M is being set to ~:M.~%") x y)
 	    (if (and $setcheckbreak (not (eq x '$setval)))
 		(let (($setval y))
 		  (merrbreak t)
@@ -807,7 +807,9 @@ wrapper for this."
   (let ((translated-args (mapcar #'translate (cdr form))))
     `($any simplify (list '(,(caar form)) ,@(mapcar #'cdr translated-args)))))
 
-(defun defstruct1 (z) ;; z will look like (($whatever) $a $b $c)
+(defun defstruct1 (z) ;; z should look like (($whatever) $a $b $c)
+  (unless (and (consp z) (consp (car z)))
+    (merror (intl:gettext "defstruct: expected a structure template; found ~M") z))
    ;; store the template
   (putprop (caar z) (namesonly z) 'defstruct-template)
   ;; set the initialization
@@ -820,20 +822,20 @@ wrapper for this."
 (defun namesonly(r)			; f(a,b,c) unchanged, f(a=3,b=4,c=5) -> f(a,b,c)
   (cons (car r)(mapcar #'(lambda(z)
 			   (cond((symbolp z) z)
-				((eq (caar z) 'mequal)(second z))
+				((mequalp z) (second z))
 				(t (merror (intl:gettext "defstruct: expected a record initializer; found: ~M") z))))
 		       (cdr r))))
 
 (defun initializersmostly(r);; f(a=3,b,c=5) -> f(3,b,5)
   (cons (car r)(mapcar #'(lambda(z)
 			   (cond((symbolp z) z)
-				((eq (caar z) 'mequal) (meval (third z)))
+				((mequalp z) (meval (third z)))
 				(t (merror (intl:gettext "defstruct: expected a record initializer; found: ~M") z))))
 		       (cdr r))))
 
 (defmspec $new (h)
   (unless (= (length (cdr h)) 1)
-    (merror (intl:gettext "~new: expected exactly one argument; found: ~M") (length (cdr h))))
+    (merror (intl:gettext "new: expected exactly one argument; found: ~M") (length (cdr h))))
 
   (let ((recordname (cadr h)))
     (cond
@@ -950,31 +952,34 @@ wrapper for this."
 		       (setq exp (maxima-substitute (meval (car item))
 						    (meval (cdr item))
 						    exp)))))
-	 (mbinding (bndvars bndvals)
-		   (if (and $numer noeval $%enumer)
-		       (setq exp (maxima-substitute %e-val '$%e exp)))
-		   (setq exp (if noeval
-				 (resimplify exp)
-				 (simplify (if predflg (mevalp exp) (meval1 exp)))))
-		   (if (or (> evflg 0) $infeval)
-		       (prog (exp1)
-			  (setq exp (specrepcheck exp))
-			  loop (do ((l evfunl (cdr l)) (exp2 exp))
-				   ((null l) (setq exp1 (meval exp2)))
-				 (setq exp2 (list (ncons (car l)) exp2)))
-			  (dolist (item subsl)
-			    (setq exp1 (maxima-substitute (meval (car item))
-							  (meval (cdr item))
-							  exp1)))
-			  (cond ((or (and (not $infeval)
-					  (= (setq evflg (1- evflg)) 0))
-				     (prog2 (setq exp1 (specrepcheck exp1))
-					 (alike1 exp exp1)))
-				 (setq exp exp1))
-				(t (setq exp exp1) (go loop)))))
-		   (if (and ratf (not $numer) (not $float))
-		       (setq exp (let ($norepeat) (ratf exp)))))
-	 (munlocal)
+	 ; Ensure that MUNLOCAL gets called so that we don't leak any local
+	 ; function definitions if we run into an error
+	 (unwind-protect
+	   (mbinding (bndvars bndvals)
+		     (if (and $numer noeval $%enumer)
+			 (setq exp (maxima-substitute %e-val '$%e exp)))
+		     (setq exp (if noeval
+				   (resimplify exp)
+				   (simplify (if predflg (mevalp exp) (meval1 exp)))))
+		     (if (or (> evflg 0) $infeval)
+			 (prog (exp1)
+			    (setq exp (specrepcheck exp))
+			    loop (do ((l evfunl (cdr l)) (exp2 exp))
+				     ((null l) (setq exp1 (meval exp2)))
+				   (setq exp2 (list (ncons (car l)) exp2)))
+			    (dolist (item subsl)
+			      (setq exp1 (maxima-substitute (meval (car item))
+							    (meval (cdr item))
+							    exp1)))
+			    (cond ((or (and (not $infeval)
+					    (= (setq evflg (1- evflg)) 0))
+				       (prog2 (setq exp1 (specrepcheck exp1))
+					   (alike1 exp exp1)))
+				   (setq exp exp1))
+				  (t (setq exp exp1) (go loop)))))
+		     (if (and ratf (not $numer) (not $float))
+			 (setq exp (let ($norepeat) (ratf exp)))))
+	   (munlocal))
 	 exp)
       (if (not (or (atom (car l))
 		   (member 'array (cdaar l) :test #'eq)
@@ -1130,8 +1135,7 @@ wrapper for this."
 	($dotassoc msetchk) ($ratwtlvl msetchk) ($ratfac msetchk)
 	($all neverset) ($numer numerset) ($fortindent msetchk)
 	($gensumnum msetchk) ($genindex msetchk) ($fpprintprec msetchk)
-	($floatwidth msetchk) ($parsewindow msetchk) ($optimprefix msetchk)
-	($ttyintnum msetchk)))
+	($floatwidth msetchk) ($parsewindow msetchk) ($optimprefix msetchk)))
 
 (defmfun msetchk (x y)
   (cond ((member x '(*read-base* *print-base*) :test #'eq)
@@ -1139,7 +1143,7 @@ wrapper for this."
 	       ((or (not (fixnump y)) (< y 2) (> y 36)) (mseterr x y))
 	       ((eq x '*read-base*))))
 	((member x '($linel $fortindent $gensumnum $fpprintprec $floatwidth
-		   $parsewindow $ttyintnum) :test #'eq)
+		   $parsewindow) :test #'eq)
 	 (if (not (fixnump y)) (mseterr x y))
          (if (eq x '$linel)
              (cond ((not (and (> y 0)         ; at least one char per line
@@ -1147,7 +1151,7 @@ wrapper for this."
                     (mseterr x y))
                    (t
                     (setq linel y))))
-	 (cond ((and (member x '($fortindent $gensumnum $floatwidth $ttyintnum) :test #'eq) (< y 0))
+	 (cond ((and (member x '($fortindent $gensumnum $floatwidth) :test #'eq) (< y 0))
 		(mseterr x y))
 	       ((and (eq x '$parsewindow) (< y -1)) (mseterr x y))
 	       ((and (eq x '$fpprintprec) (or (< y 0) (= y 1))) (mseterr x y))))
@@ -1741,7 +1745,7 @@ wrapper for this."
 	((symbolp (car x))
 	 (let ((compp (assoc (cadr x) '(($complete . t) ($integer . fixnum) ($fixnum . fixnum)
 					($float . flonum) ($flonum . flonum)))))
-	   (let ((fun ($verbify (car x)))
+	   (let ((fun (car x))
 		 (diml (cond (compp (setq compp (cdr compp))
 				    (cddr x))
 			     (t (cdr x))))
@@ -1812,57 +1816,8 @@ wrapper for this."
 ;; whereas if it is false they are stored in the function cell
 (defmvar $use_fast_arrays nil)
 
-(defmfun arrstore (l r &aux tem index)
-  (cond ($use_fast_arrays
-	 (cond ((and (boundp (caar l)) (setq tem (symbol-value (caar l))))
-		(setq index (mevalargs (cdr l)))
-		(let ((the-type (ml-typep tem)))
-		  (cond ((eq the-type 'array)
-			 (setf (apply #'aref tem index)  r))
-			((eq the-type 'hash-table)
-             ;; SINCE A "FAST ARRAY" IS JUST A HASH TABLE, SEEMS LIKE THESE !!
-             ;; TESTS ON THE NUMBER OF INDICES OBSTRUCTS LEGITIMATE HASH TABLE !!
-             ;; USE; I RECOMMEND CUTTING THEM OUT !!
-			 (cond ((gethash 'dim1 tem)
-				(if (cdr index)
-				    (merror (intl:gettext "assignment: array has one dimension, but two or more indices supplied."))))
-			       (t (or (cdr index)
-				      (merror (intl:gettext "assignment: array has two or more dimensions, but one index supplied.")))))
-			 (setf (gethash	(if (cdr index)
-					    index
-					    (car index))
-					tem) r))
-			((eq the-type 'list)
-			 (cond ((eq (caar tem) 'mlist)
-				(setq index (car index))
-				(setf (nth index tem) r)
-				r)
-			       ((eq (caar tem) '$matrix)
-				(setf (nth (second index) (nth (first index) tem)) r)
-				r)
-			       (t
-				(merror (intl:gettext "assignment: ~A is not a hash table, an array, Maxima list, or a matrix.")
-                        (caar l)))))
-			(t
-			 (cond ((eq tem (caar l))
-				(meval* `((mset) ,(caar l)
-					  ,(make-equal-hash-table
-					    (cdr (mevalargs (cdr l))))))
-				(arrstore l r))
-			       (t
-				(merror (intl:gettext "assignment: ~A is not a hash table, an array, a Maxima list, or a matrix.")
-                        (caar l))))))))
-	       (t
-		(cond ((mget (caar l) 'hashar)
-		       (let ($use_fast_arrays)
-			 (arrstore l r)))
-		      (t
-		       (meval* `((mset) ,(caar l)
-				 ,(make-equal-hash-table
-				   (cdr (mevalargs (cdr l))))))
-		       (arrstore l r))))))
-	(t
-	 (let ((fun ($verbify (caar l))) ary sub (lispsub 0) hashl mqapplyp)
+(defmfun arrstore (l r)
+	 (let ((fun (caar l)) ary sub (lispsub 0) hashl mqapplyp)
 	   (cond ((setq ary (mget fun 'array))
 		  (dimcheck fun (setq sub (mapcar #'meval (cdr l))) t)
 		  (if (and (member (setq fun (car (arraydims ary))) '(fixnum flonum) :test #'eq)
@@ -1894,7 +1849,7 @@ wrapper for this."
 		  (if (> (aref (symbol-array ary) 1) (aref (symbol-array ary) 0))
 		      (arraysize fun (* 2 (aref (symbol-array ary) 0))))
 		  r)
-		 ((and (eq fun 'mqapply) (mxorlistp (setq ary (meval (cadr l))))
+		 ((and (eq fun 'mqapply) (or (mxorlistp (setq ary (meval (cadr l)))) (arrayp ary))
 		       (prog2
 			   (setq mqapplyp t l (cdr l))
 			   nil)))
@@ -1905,13 +1860,19 @@ wrapper for this."
 		                    (typep ary 'hash-table)
 		                    (eq (type-of ary) 'mgenarray)))))
 		  (if (member fun '(mqapply $%) :test #'eq) (merror (intl:gettext "assignment: cannot assign to ~M") l))
+		  (if $use_fast_arrays
+		    (progn
+		      (format t "ARRSTORE: use_fast_arrays=true; allocate a new value hash table for ~S~%" fun)
+		      (meval* `((mset) ,fun ,(make-equal-hash-table (cdr (mevalargs (cdr l)))))))
+		    (progn
+		      (format t "ARRSTORE: use_fast_arrays=false; allocate a new property hash table for ~S~%" fun)
 		  (add2lnc fun $arrays)
 		  (setq ary (gensym))
 		  (mputprop fun ary 'hashar)
 		  (setf (symbol-array ary) (make-array 7 :initial-element nil))
 		  (setf (aref (symbol-array ary) 0) 4)
 		  (setf (aref (symbol-array ary) 1) 0)
-		  (setf (aref (symbol-array ary) 2) (length (cdr l)))
+		  (setf (aref (symbol-array ary) 2) (length (cdr l)))))
 		  (arrstore l r))
 	         ((or (arrayp ary)
 	              (typep ary 'hash-table)
@@ -1933,7 +1894,7 @@ wrapper for this."
 		 (t (if (not (= (length l) 3))
 			(merror (intl:gettext "assignment: matrix must have two indices; found: ~M") (cons '(mlist) (cdr l))))
 		    ($setelmx r (meval (cadr l)) (meval (caddr l)) ary)
-		    r))))))
+		    r))))
 
 (defun arrfunp (x)
   (or (and $transrun (getl x '(a-expr))) (mgetl x '(aexpr))))
@@ -2023,7 +1984,7 @@ wrapper for this."
   (let ($use_fast_arrays) ;;for mdefine's we allow use the oldstyle hasharrays
     (twoargcheck l)
     (setq l (cdr l))
-    (let ((fun (car l)) (body (cadr l)) args subs ary fnname mqdef redef)
+    (let ((fun (car l)) (body (cadr l)) args subs ary fnname mqdef)
       (cond ((or (atom fun)
 		 (and (setq mqdef (eq (caar fun) 'mqapply))
 		      (member 'array (cdar fun) :test #'eq)))
@@ -2032,16 +1993,18 @@ wrapper for this."
 			   (not (setq ary (member 'array (cdaadr fun) :test #'eq))))
 		       (merror (intl:gettext "define: expected a subscripted expression; found: ~M") (cadr fun)))
 		   (setq subs (cdadr fun) args (cddr fun) fun (cadr fun)
-			 fnname ($verbify (caar fun)))
+			 fnname (caar fun))
 		   (if (and (not (mgetl fnname '(hashar array)))
 			    (get fnname 'specsimp))
 		       (mtell (intl:gettext "define: warning: redefining built-in subscripted function ~:M~%")
 			      fnname)))
-	    ((prog2 (setq fnname ($verbify (caar fun)))
+	    ((prog2 (setq fnname (caar fun))
 		 (or (mopp fnname) (member fnname '($all $allbut $%) :test #'eq)))
 	     (merror (intl:gettext "define: function name cannot be a built-in operator or special symbol; found: ~:@M") fnname))
 	    ((setq ary (member 'array (cdar fun) :test #'eq)) (setq subs (cdr fun)))
-	    (t (setq args (cdr fun) redef (mredef-check fnname))))
+	    (t
+	     (setq args (cdr fun))
+	     (mredef-check fnname)))
       (if (not ary) (remove1 (ncons fnname) 'mmacro t $macros t))
       (mdefchk fnname (or args (and (not mqdef) subs)) ary mqdef)
       (if (not (eq fnname (caar fun))) (rplaca (car fun) fnname))
@@ -2178,10 +2141,10 @@ wrapper for this."
 (defun consfundef (x maexprp stringp)
   (prog (arryp name fun)
      (setq arryp (and (not (atom x)) (not (eq (caar x) 'mqapply)) (member 'array (cdar x) :test #'eq)))
-     (cond ((atom x) (setq name ($verbify x)
+     (cond ((atom x) (setq name (if (stringp x) ($verbify x) x)
 			   fun (or (and (not maexprp) (mgetl name '(mexpr mmacro)))
 				   (mgetl name '(aexpr)))))
-	   (arryp (setq fun (meval1 (setq name (cons (list ($verbify (caar x)) 'array) (cdr x)))))
+	   (arryp (setq fun (meval1 (setq name (cons (list (caar x) 'array) (cdr x)))))
 		  (if (or (atom fun) (not (eq (caar fun) 'lambda))) (setq fun nil))))
      (cond ((not fun)
             (cond (stringp (return x)) 
