@@ -113,7 +113,7 @@
   (prog (varlist newvarlist dontdisrepit $ratfac genvar $keepfloat)
      ;; hard to maintain user ordering info.
      (if ($ratp c) (setq dontdisrepit t))
-     (when (and $radsubstflag
+     (if (and $radsubstflag
 		(prog2 (newvar b) (some #'mexptp varlist)))
        (let (($factorflag t) *exp *exp2 *radsubst)
 	 (setq b (fullratsimp b))
@@ -127,7 +127,8 @@
 	 (setq *radsubst t)
 	 (spc0)
 	 (setq b (rdis *exp) c (rdis *exp2))
-	 (setq varlist nil)))
+	 (setq varlist nil))
+       (setq varlist nil))
      (setq a ($ratdisrep a) b ($ratdisrep b) c ($ratdisrep c))
      (cond ((integerp b) (setq c (ratf (maxima-substitute a b c)))
 	    (return (cond (dontdisrepit c) (t ($ratdisrep c))))))
@@ -373,9 +374,29 @@
 	 (cond ((not (freeofl var (hand-side (caddr e) 'r))) nil)
 	       ((not (freeofl var (hand-side (caddr e) 'l))) t)
 	       (t (freeof var (cadr e)))))
-	((and (eq (caar e) 'lambda) (member var (cdadr e) :test #'eq)) t)
+        ((and (eq (caar e) 'lambda)
+              (not (member 'array (cdar e) :test #'eq))
+              ($listp (cadr e))
+              ; Check if var appears in the lambda list in any of the
+              ; following ways: var, 'var, [var] or ['var].
+              (some (lambda (v)
+                      (or (eq v var)
+                          (alike1 v `((mquote) ,var))
+                          (alike1 v `((mlist) ,var))
+                          (alike1 v `((mlist) ((mquote) ,var)))))
+                    (cdadr e)))
+         t)
         ;; Check for a local variable in a block.
-        ((and (eq (caar e) 'mprog) (member var (cdadr e) :test #'eq)) t)
+        ((and (eq (caar e) 'mprog)
+              ($listp (cadr e))
+              ; Check if var appears in the variable list alone or
+              ; in an assignment
+              (some (lambda (v)
+                      (or (eq v var)
+                          (and (msetqp v)
+                               (eq (cadr v) var))))
+                    (cdadr e)))
+         t)
         ;; Check for a loop variable.
         ((and (eq (caar e) 'mdo) (alike1 var (cadr e))) t)
 	(argsfreeofp (freeofl var (margs e)))
